Threading
=========

Asynchronous workers for GUI responsiveness and parallel processing.

.. currentmodule:: xpcsviewer.threading

Async Workers
-------------

.. automodule:: xpcsviewer.threading.async_workers
   :members:
   :undoc-members:
   :show-inheritance:

Async Kernel
------------

.. automodule:: xpcsviewer.threading.async_kernel
   :members:
   :undoc-members:
   :show-inheritance:

Plot Workers
------------

.. automodule:: xpcsviewer.threading.plot_workers
   :members:
   :undoc-members:
   :show-inheritance:

Base Plot Worker
~~~~~~~~~~~~~~~~

.. automodule:: xpcsviewer.threading.base_plot_worker
   :members:
   :undoc-members:
   :show-inheritance:

GUI Integration
---------------

.. automodule:: xpcsviewer.threading.gui_integration
   :members:
   :undoc-members:
   :show-inheritance:

Unified Threading
-----------------

.. automodule:: xpcsviewer.threading.unified_threading
   :members:
   :undoc-members:
   :show-inheritance:

Cleanup Optimization
--------------------

.. automodule:: xpcsviewer.threading.cleanup_optimized
   :members:
   :undoc-members:
   :show-inheritance:

Progress Management
-------------------

.. automodule:: xpcsviewer.threading.progress_manager
   :members:
   :undoc-members:
   :show-inheritance:
